==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebPaneDragActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescription } from "./WebPaneDragActionDescription";
/**
 * @hidden
 */
var WebPaneDragActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragActionDescriptionMetadata, _super);
    function WebPaneDragActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragActionDescriptionMetadata.b = function (a) {
        if (WebPaneDragActionDescriptionMetadata.a == null) {
            WebPaneDragActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragActionDescriptionMetadata.c(WebPaneDragActionDescriptionMetadata.a);
        }
        if (a.g(WebPaneDragActionDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneDragActionDescriptionMetadata.a);
    };
    WebPaneDragActionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragAction");
    };
    WebPaneDragActionDescriptionMetadata.d = function (a) {
        WebPaneDragActionDescriptionMetadata.b(a);
        a.u("WebPaneDragAction", function () { return new WebPaneDragActionDescription(); });
        a.t("WebPaneDragAction", WebPaneDragActionDescriptionMetadata.a);
    };
    WebPaneDragActionDescriptionMetadata.$t = markType(WebPaneDragActionDescriptionMetadata, 'WebPaneDragActionDescriptionMetadata');
    WebPaneDragActionDescriptionMetadata.a = null;
    return WebPaneDragActionDescriptionMetadata;
}(Base));
export { WebPaneDragActionDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebPaneDragActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescription } from "./WebPaneDragActionDescription";
/**
 * @hidden
 */
var WebPaneDragActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneDragActionDescriptionMetadata, _super);
    function WebPaneDragActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragActionDescriptionMetadata.b = function (a) {
        if (WebPaneDragActionDescriptionMetadata.a == null) {
            WebPaneDragActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragActionDescriptionMetadata.c(WebPaneDragActionDescriptionMetadata.a);
        }
        if (a.j(WebPaneDragActionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPaneDragActionDescriptionMetadata.a);
    };
    WebPaneDragActionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragAction");
    };
    WebPaneDragActionDescriptionMetadata.d = function (a) {
        WebPaneDragActionDescriptionMetadata.b(a);
        a.aa("WebPaneDragAction", function () { return new WebPaneDragActionDescription(); });
        a.z("WebPaneDragAction", WebPaneDragActionDescriptionMetadata.a);
    };
    WebPaneDragActionDescriptionMetadata.$t = markType(WebPaneDragActionDescriptionMetadata, 'WebPaneDragActionDescriptionMetadata');
    WebPaneDragActionDescriptionMetadata.a = null;
    return WebPaneDragActionDescriptionMetadata;
}(Base));
export { WebPaneDragActionDescriptionMetadata };
